@@ -63,7 +63,9 @@
  *  <title>Writing a Playlist</title>
  *  <programlisting>
  * void
- * parser_func (GtkTreeModel *model, GtkTreeIter *iter, gchar **uri, gchar **title, gboolean *custom_title, gpointer user_data)
+ * parser_func (GtkTreeModel *model, GtkTreeIter *iter,
+ * 		gchar **uri, gchar **title, gboolean *custom_title,
+ * 		gpointer user_data)
  * {
  * 	gtk_tree_model_get (model, iter,
  * 		0, uri,
@@ -83,8 +85,10 @@
  * 	tree_model = gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN);
  * 	populate_model (tree_model);
  *
- * 	if (totem_pl_parser_write (pl, tree_model, parser_func, "/tmp/playlist.pls", TOTEM_PL_PARSER_PLS, NULL, NULL) != TRUE)
+ * 	if (totem_pl_parser_write (pl, tree_model, parser_func, "/tmp/playlist.pls",
+ * 				   TOTEM_PL_PARSER_PLS, NULL, NULL) != TRUE) {
  * 		g_error ("Playlist writing failed.");
+ * 	}
  *
  * 	g_object_unref (tree_model);
  * 	g_object_unref (pl);
@@ -166,6 +170,7 @@ static PlaylistTypes special_types[] = {
 	PLAYLIST_TYPE ("audio/x-scpls", totem_pl_parser_add_pls, NULL, FALSE),
 	PLAYLIST_TYPE ("application/x-smil", totem_pl_parser_add_smil, NULL, FALSE),
 	PLAYLIST_TYPE ("application/smil", totem_pl_parser_add_smil, NULL, FALSE),
+	PLAYLIST_TYPE ("application/vnd.ms-wpl", totem_pl_parser_add_smil, NULL, FALSE),
 	PLAYLIST_TYPE ("video/x-ms-wvx", totem_pl_parser_add_asx, NULL, FALSE),
 	PLAYLIST_TYPE ("audio/x-ms-wax", totem_pl_parser_add_asx, NULL, FALSE),
 	PLAYLIST_TYPE ("application/xspf+xml", totem_pl_parser_add_xspf, NULL, FALSE),
@@ -1443,9 +1448,10 @@ totem_pl_parser_parse_internal (TotemPlParser *parser,
 
 	if (g_file_has_uri_scheme (file, "mms") != FALSE
 			|| g_file_has_uri_scheme (file, "rtsp") != FALSE
+			|| g_file_has_uri_scheme (file, "rtmp") != FALSE
 			|| g_file_has_uri_scheme (file, "icy") != FALSE
 			|| g_file_has_uri_scheme (file, "pnm") != FALSE) {
-		DEBUG(file, g_print ("URI '%s' is MMS, RTSP, PNM or ICY, not a playlist\n", uri));
+		DEBUG(file, g_print ("URI '%s' is MMS, RTSP, RTMP, PNM or ICY, not a playlist\n", uri));
 		return TOTEM_PL_PARSER_RESULT_UNHANDLED;
 	}
 
